summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--src/Noddybox.Emulation/Clock.cs5
1 files changed, 3 insertions, 2 deletions
diff --git a/src/Noddybox.Emulation/Clock.cs b/src/Noddybox.Emulation/Clock.cs
index 7347900..4765086 100644
--- a/src/Noddybox.Emulation/Clock.cs
+++ b/src/Noddybox.Emulation/Clock.cs
@@ -103,9 +103,9 @@ namespace Noddybox.Emulation
public ulong TotalCyclesPerFrame {get; private set;}
/// <summary>
/// Gets the number of ticks since the last event.
/// </summary>
- public uint Cycles {get {return cycles;}}
+ public uint CycleCount {get; set;}
#endregion
@@ -118,6 +118,7 @@ namespace Noddybox.Emulation
public void Add(uint ticks)
{
cycles += ticks;
+ CycleCount += ticks;
// Check pre-frame end
//
@@ -103,9 +103,9 @@ namespace Noddybox.Emulation
public ulong TotalCyclesPerFrame {get; private set;}
/// <summary>
- /// Gets the number of ticks since the last event.
+ /// Gets the number of ticks since the last time the count was reset from here.
/// </summary>